==> netcdf-4.1.2.tar.gz: netcdf-4.1.2/libcdmr/curlwrap.h <==
/*
 * Copyright 1993-1996 University Corporation for Atmospheric Research/Unidata
 * 
 * Portions of this software were developed by the Unidata Program at the 
 * University Corporation for Atmospheric Research.
 * 
 * Access and use of this software shall impose the following obligations
 * and understandings on the user. The user is granted the right, without
 * any fee or cost, to use, copy, modify, alter, enhance and distribute
 * this software, and any derivative works thereof, and its supporting
 * documentation for any purpose whatsoever, provided that this entire
 * notice appears in all copies of the software, derivative works and
 * supporting documentation.  Further, UCAR requests that the user credit
 * UCAR/Unidata in any publications that result from the use of this
 * software or in any product that includes this software. The names UCAR
 * and/or Unidata, however, may not be used in any advertising or publicity
 * to endorse or promote any products or commercial entity unless specific
 * written permission is obtained from UCAR/Unidata. The user also
 * understands that UCAR/Unidata is not obligated to provide the user with
 * any support, consulting, training or assistance of any kind with regard
 * to the use, operation and performance of this software nor to provide
 * the user with any updates, revisions, new versions or "bug fixes."
 * 
 * THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */
/* "$Id$" */

#ifndef CURLWRAP_H
#define CURLWRAP_H

extern int nc_curlopen(CURL**);
extern void nc_curlclose(CURL*);

extern int nc_set_curl_flags(CURL*, NCCDMR*);
extern int nc_set_proxy(CURL*, NCCDMR*);
extern int nc_set_ssl(CURL*, NCCDMR*);
extern int nc_set_user_password(CURL*, const char *userC, const char *passwordC);

#ifdef IGNORE
extern long nc_fetchhttpcode(CURL*);
extern int nc_fetchurl_file(CURL*, char* url, FILE* stream, unsigned long* sizep, long* filetime);
extern int nc_fetchurl(CURL*, char* url, NCbytes* buf, long* filetime);
extern int nc_fetchlastmodified(CURL*, char* url, long* filetime);
#endif

#endif /*CURLWRAP_H*/

==> netcdf_4.1.3.orig.tar.gz: netcdf-4.1.3/libcdmr/curlwrap.h <==
/*
 * Copyright 1993-1996 University Corporation for Atmospheric Research/Unidata
 * 
 * Portions of this software were developed by the Unidata Program at the 
 * University Corporation for Atmospheric Research.
 * 
 * Access and use of this software shall impose the following obligations
 * and understandings on the user. The user is granted the right, without
 * any fee or cost, to use, copy, modify, alter, enhance and distribute
 * this software, and any derivative works thereof, and its supporting
 * documentation for any purpose whatsoever, provided that this entire
 * notice appears in all copies of the software, derivative works and
 * supporting documentation.  Further, UCAR requests that the user credit
 * UCAR/Unidata in any publications that result from the use of this
 * software or in any product that includes this software. The names UCAR
 * and/or Unidata, however, may not be used in any advertising or publicity
 * to endorse or promote any products or commercial entity unless specific
 * written permission is obtained from UCAR/Unidata. The user also
 * understands that UCAR/Unidata is not obligated to provide the user with
 * any support, consulting, training or assistance of any kind with regard
 * to the use, operation and performance of this software nor to provide
 * the user with any updates, revisions, new versions or "bug fixes."
 * 
 * THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */
/* "$Id$" */

#ifndef CURLWRAP_H
#define CURLWRAP_H

/*Forward*/
struct NCCDMR;
struct bytes_t;

extern int nccr_curlopen(CURL**);
extern int nccr_curlclose(CURL*);

extern int nccr_fetchurl(CURL* curl, char* url, struct bytes_t* buf, long* filetime);
extern long nccr_fetchhttpcode(CURL* curl);
extern int nccr_fetchlastmodified(CURL* curl, char* url, long* filetime);

extern int nccr_set_curl_flags(CURL*, struct NCCDMR*);
extern int nccr_set_proxy(CURL*, struct NCCDMR*);
extern int nccr_set_ssl(CURL*, struct NCCDMR*);
extern int nccr_set_user_password(CURL*, const char *userC, const char *passwordC);


#endif /*CURLWRAP_H*/
